#
# spec file for package python-python-gitlab
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-python-gitlab
Version:        1.11.0
Release:        bp154.1.21
Summary:        Python module for interacting with the GitLab API
License:        LGPL-3.0-only
Group:          Development/Languages/Python
URL:            https://github.com/python-gitlab/python-gitlab
Source:         https://files.pythonhosted.org/packages/source/p/python-gitlab/python-gitlab-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-requests >= 2.4.2
Requires:       python-setuptools
Requires:       python-six
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module httmock}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module requests >= 2.4.2}
BuildRequires:  %{python_module six}
# /SECTION
%python_subpackages

%description
The python-gitlab package provides access to the GitLab server API.

It supports the v4 API of GitLab, and provides a CLI tool (gitlab).

%prep
%setup -q -n python-gitlab-%{version}
# rpmlint non-executable-script
sed -i -e '/^#!\//, 1d' gitlab/cli.py
sed -i -e '/^#!\//, 1d' gitlab/tests/test_cli.py
sed -i -e '/^#!\//, 1d' gitlab/v4/cli.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec setup.py test

%files %{python_files}
%doc AUTHORS ChangeLog.rst README.rst
%license COPYING
%python3_only %{_bindir}/gitlab
%{python_sitelib}/*

%changelog
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.11.0:
  * add methods to retrieve an individual project environment
  * group labels with subscriptable mixin
  * add mr rebase method bc4280c
  * get artifact by ref and job cda1174
  * add support for board update 908d79f, closes #801
  * add support for issue.related_merge_requests 90a3631, closes #794
* Mon Jul 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.9.0:
  * implement artifacts deletion
  * add endpoint to get the variables of a pipeline
  * delete ProjectPipeline
  * implement __eq__ and __hash__ methods
  * Allow runpy invocation of CLI tool (python -m gitlab)
  * add project releases api
  * merged new release & registry apis
* Thu May  9 2019 pgajdos@suse.com
- version update to 1.8.0
  * fix(api): make reset_time_estimate() work again
  * fix: handle empty 'Retry-After' header from GitLab
  * fix: remove decode() on error_message string
  * fix(api): avoid parameter conflicts with python and gitlab
  * fix(api): Don't try to parse raw downloads
  * feat: Added approve & unapprove method for Mergerequests
  * fix all kwarg behaviour
* Mon Dec 31 2018 Thomas Bechtold <tbechtold@suse.com>
- update to 1.7.0:
  * [docs] Fix the owned/starred usage documentation
  * [docs] Add a warning about http to https redirects
  * Fix the https redirection test
  * [docs] Add a note about GroupProject limited API
  * Add missing comma in ProjectIssueManager _create_attrs
  * More flexible docker image
  * Add project protected tags management
  * [cli] Print help and usage without config file
  * Rename MASTER_ACCESS to MAINTAINER_ACCESS
  * [docs] Add docs build information
  * Use docker image with current sources
  * [docs] Add PyYAML requirement notice
  * Add Gitter badge to README
  * [docs] Add an example of pipeline schedule vars listing
  * [cli] Exit on config parse error, instead of crashing
  * Add support for resource label events
  * [docs] Fix the milestone filetring doc (iid -> iids)
  * [docs] Fix typo in custom attributes example
  * Improve error message handling in exceptions
  * Add support for members all() method
  * Add access control options to protected branch creation
  * [docs] Don't use hardcoded values for ids
  * [docs] Improve the snippets examples
  * [cli] Output: handle bytes in API responses
  * [cli] Fix the case where we have nothing to print
  * Project import: fix the override_params parameter
  * Support group and global MR listing
  * Implement MR.pipelines()
  * MR: add the squash attribute for create/update
  * Added support for listing forks of a project
  * [docs] Add/update notes about read-only objects
  * Raise an exception on https redirects for PUT/POST
  * [docs] Add a FAQ
  * [cli] Fix the project-export download
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Aug  8 2018 jengelh@inai.de
- Use noun phrase in summary.
* Fri Aug  3 2018 toddrme2178@gmail.com
- Initial version
